#! /bin/sh
#------------------------------------------------------------------------------
# /var/install/config.d/mod_jk - mod_jk configuration
#
# Copyright (c) 2007-2008 Sebastian Scholze <webmaster(at)schlotze(dot)de
#
# Creation   : 2007-02-28 scholze
# Last update: $Id: mod_jk.sh 30577 2012-04-21 20:36:50Z schlotze $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

#exec 2>/public/mod_jk-trace$$.log
#set -x

#---------------------------------------------------------------------------
# config Dateien
#---------------------------------------------------------------------------
. /var/install/include/eislib
. /etc/config.d/mod_jk
. /etc/config.d/apache2

updated=`date '+%Y-%m-%d %H:%M:%S'`
pgmname=$0

#
jkConf=/etc/apache2/mods-available/mod_jk.conf
workerConf=/etc/apache2/mods-available/workers.properties
packages_name=mod_jk
logroot=`dirname $APACHE2_ERROR_LOG`

#----------------------------------------------------------------------------------------
# 
#----------------------------------------------------------------------------------------
check_httpd ()
{
    retval=0
}

#----------------------------------------------------------------------------------------
# create mod_jk config
#----------------------------------------------------------------------------------------
create_mod_jk_config ()
{
    cat > /etc/apache2/mods-available/mod_jk.load <<EOF
LoadModule jk_module /usr/local/apache2/modules/mod_jk.so
EOF

   	# edit mod_jk.conf
	{
		echo "# Where to find workers.properties"
		echo "JkWorkersFile $workerConf"
		echo "# Where to put jk shared memory"
		echo "JkShmFile     /var/lib/apache/mod_jk.shm"
		echo "# Where to put jk logs"
		echo "JkLogFile     ${logroot}/mod_jk.log"
		echo "# Set the jk log level [debug/error/info]"
		echo "JkLogLevel    info"
		echo "# Select the timestamp log format"
		echo "JkLogStampFormat \"[%a %b %d %H:%M:%S %Y] \""

		idx=1
		#for idx in `ls $vhost_path`
		while [ "$idx" -le "$JK_MOUNT_N" ]
		do
			eval active='$JK_MOUNT_'$idx'_ACTIVE'
			eval url='$JK_MOUNT_'$idx'_URL'
			if [ "$active" = "yes" ]
    		then
				echo "JkMount  $url tomcat"
			fi
			idx=`expr $idx + 1`
		done
		echo ""

		if [ "$JK_STATUS" = "yes" ]
		then
			echo "JkMount /jkstatus jkstatus"
		fi
		
		echo ""
		echo "JkMountCopy All"
	} >$jkConf

   	# edit workers.properties
	{
		echo "# workers.properties.minimal -"
		echo "#"
		echo "# This file provides minimal jk configuration properties needed to"
		echo "# connect to Tomcat."
		echo "#"
		# The workers that jk should create and work with"
		echo "#"
		echo ""
		echo "worker.list=wlb,jkstatus,tomcat"
		echo ""
		echo "#"
		echo "# Defining a worker named ajp13w and of type ajp13"
		echo "# Note that the name and the type do not have to match."
		echo "#"
		echo "worker.tomcat.type=ajp13"
		echo "worker.tomcat.host=$JK_TOMCAT_HOST"
		echo "worker.tomcat.port=$JK_TOMCAT_PORT"
		echo ""
		echo "#"
		echo "# Defining a load balancer"
		echo "#" 
		echo ""
		echo "worker.wlb.type=lb"
		echo "worker.wlb.balance_workers=tomcat"
		echo ""
		echo "#"
		echo "# Define status worker"
		echo "#"
		echo ""
		echo "worker.jkstatus.type=status"
	} >$workerConf

}

### ------------------------------------------------------------------------
### Main
### ------------------------------------------------------------------------

case "$1"
in
    check_httpd)
        check_httpd
    ;;
    unistall)
		mecho -std "mod_jk configuration is de-activated."
    ;;
    *)
    	# edit conf
		create_mod_jk_config
		
		# execute apache2 update script
		if [ -f /var/install/config.d/apache2.sh ]
		then
			/var/install/config.d/apache2.sh
		fi
		ln -sf /etc/apache2/mods-available/mod_jk.load /etc/apache2/mods-enabled/mod_jk.load
		ln -sf /etc/apache2/mods-available/mod_jk.conf /etc/apache2/mods-enabled/mod_jk.conf

		# reload apache2 configuration if apache is running
		if [ -f /var/run/httpd.pid -a -f /etc/init.d/apache2 ]
		then
			/etc/init.d/apache2 restart
		fi
		mecho -std "mod_jk configuration is activated."
    ;;
esac

### ------------------------------------------------------------------------
### end
### ------------------------------------------------------------------------
exit 0
